@@ -27,29 +27,43 @@ sub run {
 
     my $rc = get_perltidyrc();
 
-    open( my $fh, '-|', 'git status --porcelain' ) || die "open: $!";
+    # Use the -z flag to get clean filenames with no escaping or quoting
+    # "lines" are separated with NUL, so set input record separator
+    # appropriately
+    {
+        local $/ = "\0";
+        open( my $fh, '-|', 'git status --porcelain -z' ) || die "open: $!";
 
-    while ( my $line = <$fh> ) {
-        chomp $line;
-        next unless $line =~ m/^(.)(.) (.*)/;
+        while ( my $line = <$fh> ) {
+            chomp $line;
+            next unless $line =~ m/^(.)(.) (.*)/;
 
-        my ( $index, $wtree, $file ) = ( $1, $2, $3 );
-        $partial++ if $wtree eq 'M';
-        next unless ( $index eq 'A' or $index eq 'M' );
+            my ( $index, $wtree, $file ) = ( $1, $2, $3 );
+            $partial++ if $wtree eq 'M';
+            next unless ( $index eq 'A' or $index eq 'M' );
 
-        if ( $file !~ m/\.(pl|pod|pm|t)$/i ) {
-            open( my $fh2, '<', $file ) || die "open $file: $!";
-            my $possible = <$fh2> || next;
+            if ( $file !~ m/\.(pl|pod|pm|t)$/i ) {
 
-            #        warn $possible;
-            next unless $possible =~ m/^#!.*perl\W/;
+              # reset line separator to newline when checking first line of file
+                local $/ = "\n";
+                open( my $fh2, '<', $file ) || die "open $file: $!";
+                my $possible = <$fh2> || next;
+
+                #        warn $possible;
+                next
+                  unless $possible =~ m/^#!.*perl\W/
+                  or $possible =~ m/^#!.*\.plenv\W/;
+            }
+
+            push( @perlfiles, $file );
+            $partial{$file} = $file . '|' . ( $wtree eq 'M' ? 1 : 0 );
         }
-
-        push( @perlfiles, $file );
-        $partial{$file} = $file . '|' . ( $wtree eq 'M' ? 1 : 0 );
     }
 
-    exit 0 unless @perlfiles;
+    if ( !@perlfiles ) {
+        print "$me pre-commit: no changes to tidy\n";
+        exit 0;
+    }
 
     print "$me pre-commit:\n    # saving non-indexed changes and tidying\n";
 
@@ -62,12 +76,12 @@ sub run {
     sys(qw/git checkout-index -a /);
 
     my $have_podtidy_opts = have_podtidy_opts();
-    warn "Skipping podtidy calls: no .podtidy-opts file"
+    print "    Skipping podtidy calls: no .podtidy-opts file\n"
       unless $have_podtidy_opts;
 
     foreach my $file (@perlfiles) {
         if ($have_podtidy_opts) {
-            print "podtidy $file\n";
+            print "    podtidy $file\n";
 
             Pod::Tidy::tidy_files(
                 files     => [$file],
@@ -85,8 +99,8 @@ sub run {
         unless ( $file =~ m/\.pod$/i ) {
             unlink $file . '.ERR';
 
-            print "perltidy $file\n";
-            Perl::Tidy::perltidy(
+            print "    perltidy --profile=$rc -nst -b -bext=.bak $file\n";
+            my $error = Perl::Tidy::perltidy(
                 argv => [ '--profile=' . $rc, qw/-nst -b -bext=.bak/, $file ],
             );
 
@@ -94,6 +108,9 @@ sub run {
             if ( -e $file . '.ERR' ) {
                 die path( $file . '.ERR' )->slurp;
             }
+            elsif ($error) {
+                die "$me pre-commit: An unknown error occurred.";
+            }
         }
     }
 
